@@ -57,6 +57,7 @@ from nise.generators.azure import VNGenerator
 from nise.generators.gcp import CloudStorageGenerator
 from nise.generators.gcp import ComputeEngineGenerator
 from nise.generators.gcp import GCP_REPORT_COLUMNS
+from nise.generators.gcp import GCP_RESOURCE_COLUMNS
 from nise.generators.gcp import GCPDatabaseGenerator
 from nise.generators.gcp import GCPNetworkGenerator
 from nise.generators.gcp import JSONLCloudStorageGenerator
@@ -911,7 +912,10 @@ def write_gcp_file(start_date, end_date, data, options):
         file_name = report_prefix + ".csv"
     local_file_path = "{}/{}".format(os.getcwd(), file_name)
     output_file_name = f"{etag}/{file_name}"
-    _write_csv(local_file_path, data, GCP_REPORT_COLUMNS)
+    columns = GCP_REPORT_COLUMNS
+    if options.get("gcp_resource_level", False):
+        columns += GCP_RESOURCE_COLUMNS
+    _write_csv(local_file_path, data, columns)
     return local_file_path, output_file_name
 
 
@@ -948,6 +952,7 @@ def gcp_create_report(options):  # noqa: C901
     end_date = options.get("end_date")
 
     static_report_data = options.get("static_report_data")
+    resource_level = options.get("gcp_resource_level", False)
 
     if gcp_dataset_name:
         # if the file is supposed to be uploaded to a bigquery table, it needs the JSONL version of everything
@@ -1050,13 +1055,14 @@ def gcp_create_report(options):  # noqa: C901
                 for count, generator in enumerate(generators):
                     attributes = generator.get("attributes", {})
                     if attributes:
-                        start_date = attributes.get("start_date")
-                        end_date = attributes.get("end_date")
+                        start_date = attributes.get("start_date", start_date)
+                        end_date = attributes.get("end_date", end_date)
                         currency = default_currency(options.get("currency"), attributes.get("currency"))
                     else:
                         currency = default_currency(options.get("currency"), None)
                     if gen_end_date > end_date:
                         gen_end_date = end_date
+                    attributes["resource_level"] = resource_level
 
                     generator_cls = generator.get("generator")
                     gen = generator_cls(gen_start_date, gen_end_date, currency, project, attributes=attributes)
@@ -1082,7 +1088,7 @@ def gcp_create_report(options):  # noqa: C901
 def _gcp_bigquery_process(
     start_date, end_date, currency, projects, generators, options, gcp_bucket_name, gcp_dataset_name, gcp_table_name
 ):
-
+    resource_level = options.get("gcp_resource_level", False)
     data = []
     for project in projects:
         num_gens = len(generators)
@@ -1091,8 +1097,9 @@ def _gcp_bigquery_process(
         for count, generator in enumerate(generators):
             attributes = generator.get("attributes", {})
             if attributes:
-                start_date = attributes.get("start_date")
-                end_date = attributes.get("end_date")
+                start_date = attributes.get("start_date", start_date)
+                end_date = attributes.get("end_date", end_date)
+            attributes["resource_level"] = resource_level
 
             generator_cls = generator.get("generator")
             gen = generator_cls(start_date, end_date, currency, project, attributes=attributes)
@@ -1111,8 +1118,11 @@ def _gcp_bigquery_process(
 
     if not gcp_table_name:
         etag = options.get("gcp_etag") if options.get("gcp_etag") else str(uuid4())
-        gcp_table_name = f"gcp_billing_export_{etag}"
-    gcp_bucket_to_dataset(gcp_bucket_name, output_file_name, gcp_dataset_name, gcp_table_name)
+        if resource_level:
+            gcp_table_name = f"gcp_billing_export_resource_{etag}"
+        else:
+            gcp_table_name = f"gcp_billing_export_{etag}"
+    gcp_bucket_to_dataset(gcp_bucket_name, output_file_name, gcp_dataset_name, gcp_table_name, resource_level)
 
     return monthly_files
 
@@ -1158,22 +1168,19 @@ def oci_bucket_upload(bucket_name, report_type, month, year, data, options):
 
 def oci_create_report(options):
     """Create cost and usage report files."""
+
     start_date = options.get("start_date")
     end_date = options.get("end_date")
-    fake = Faker()
-    attributes = {}
-    attributes["tenant_id"] = f"ocid1.tenancy.oc1..{fake.pystr(min_chars=20, max_chars=30)}"
-    attributes["compartment_name"] = fake.name().replace(" ", "").lower()
     static_report_data = options.get("static_report_data")
 
     if static_report_data:
         generators = _get_generators(static_report_data.get("generators"))
     else:
         generators = [
-            {"generator": OCIComputeGenerator, "attributes": attributes},
-            {"generator": OCIBlockStorageGenerator, "attributes": attributes},
-            {"generator": OCINetworkGenerator, "attributes": attributes},
-            {"generator": OCIDatabaseGenerator, "attributes": attributes},
+            {"generator": OCIComputeGenerator},
+            {"generator": OCIBlockStorageGenerator},
+            {"generator": OCINetworkGenerator},
+            {"generator": OCIDatabaseGenerator},
         ]
     months = _create_month_list(start_date, end_date)
     currency = default_currency(options.get("currency"), static_currency=None)
@@ -1187,10 +1194,16 @@ def oci_create_report(options):
 
         for generator in generators:
             generator_cls = generator.get("generator")
-            attributes = generator.get("attributes")
+            attributes = generator.get("attributes", {})
 
-            if static_report_data:
+            if attributes:
+                # Skip if generator usage is outside of current month
+                if attributes.get("end_date") < month.get("start"):
+                    continue
+                if attributes.get("start_date") > month.get("end"):
+                    continue
                 currency = attributes.get("currency")
+                gen_start_date, gen_end_date = _create_generator_dates_from_yaml(attributes, month)
 
             gen = generator_cls(gen_start_date, gen_end_date, currency, attributes)
             for report_type in OCI_REPORT_TYPE_TO_COLS:
